# runtime.data

## Purpose
Domain runtime primitives for data.

## Owns
- Modules under `vyro.runtime.data`.

## Entry Points
- `vyro.runtime.data`

## Not Here
- Public app composition (`vyro.app`).
